@@ -12,22 +12,31 @@ import json
 
 from pymatgen.serializers.json_coders import MSONable
 
+__all__ = [
+    "EventParser",
+]
 
 class Event(MSONable):
     """
-    Example (JSON)
+    Example (JSON)::
 
-    <Event>
-        "class": "ScfConvergenceWarning",
-        "src_file": "routine name",
-        "src_line": "line number in src_file",
-        "message": "The human-readable message goes here!"
-        "tolname": "tolwfr",
-        "actual_tol": 1.0e-8,
-        "required_tol": 1.0e-10,
-        "nstep": 50,
-    </Event>
+        <Event>
+            "class": "ScfConvergenceWarning",
+            "src_file": "routine name",
+            "src_line": "line number in src_file",
+            "message": "The human-readable message goes here!"
+            "tolname": "tolwfr",
+            "actual_tol": 1.0e-8,
+            "required_tol": 1.0e-10,
+            "nstep": 50,
+        </Event>
     """
+    def __init__(self, **kwargs):
+        self._kwargs = kwargs.copy()
+        self.message = kwargs.pop("message")
+        self.lineno  = kwargs.pop("lineno")
+        self.data = kwargs
+
     @staticmethod
     def from_string(string, lineno):
         """Constructs an event given a string and the line number."""
@@ -37,12 +46,6 @@ class Event(MSONable):
         d["lineno"] = lineno
         return cls(d)
 
-    def __init__(self, **kwargs):
-        self._kwargs = kwargs.copy()
-        self.message = kwargs.pop("message")
-        self.lineno  = kwargs.pop("lineno")
-        self.data = kwargs
-
     def __str__(self):
         return "%s:\n%s" % (self.lineno, self.message)
 
@@ -159,13 +162,13 @@ class EventList(collections.Iterable, MSONable):
         return "\n".join(l for l in lines)
 
     def append(self, event):
-        "Add an event to the list."
+        """Add an event to the list."""
         self._events.append(event)
         self._events_by_baseclass[event.baseclass].append(event)
 
     @property
     def critical_events(self):
-        "List of critical events"
+        """List of critical events."""
         return [e for e in self if e.iscritical]
 
     @property
@@ -184,12 +187,25 @@ class EventList(collections.Iterable, MSONable):
     def warnings(self):
         return self.select(Warning)
 
+    @property
+    def num_warnings(self):
+        return len(self.warnings)
+
+    @property
+    def num_errors(self):
+        return len(self.errors)
+
+    @property
+    def num_comments(self):
+        return len(self.comments)
+
     def select(self, base_class, only_critical=False):
         """
         Return list of events that inherits from class base_class
 
-        only_critical:
-            if True, only critical events are returned.
+        Args:
+            only_critical:
+                if True, only critical events are returned.
         """
         if only_critical:
             return [e for e in self._events_by_baseclass[base_class] if e.iscritical]
@@ -219,8 +235,7 @@ class EventParserError(Exception):
 
 class EventParser(object):
     """
-    Parses the output or the log file produced by abinit and extract the list
-    of events.
+    Parses the output or the log file produced by abinit and extract the list of events.
     """
     Error = EventParserError
 
