@@ -326,7 +326,10 @@ class SymmetryFinder(object):
             lattice, pos, numbers, num_atom, self._symprec, self._angle_tol)
         zs = numbers[:num_atom_bravais]
         species = [self._unique_species[i - 1] for i in zs]
-        s = Structure(lattice.T.copy(), species, pos[:num_atom_bravais])
+        s = Structure(lattice.T.copy(), 
+                      species,
+                      pos[:num_atom_bravais],
+                      site_properties=self._structure.site_properties)
         return s.get_sorted_structure()
 
     def find_primitive(self):
