@@ -13,8 +13,7 @@ __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __date__ = "Mar 9, 2012"
 
-import itertools
-
+import numpy as np
 from pymatgen.core.structure import Structure
 
 
@@ -24,6 +23,10 @@ class SymmetrizedStructure(Structure):
     where the spacegroup and symmetry operations are defined. This class is
     typically not called but instead is typically obtained by calling
     pymatgen.symmetry.SymmetryFinder.get_symmetrized_structure.
+    
+    .. attribute: equivalent_indices
+        
+        indices of structure grouped by equivalency
     """
 
     def __init__(self, structure, spacegroup, equivalent_positions):
@@ -41,13 +44,14 @@ class SymmetrizedStructure(Structure):
                             for site in structure],
                            structure.frac_coords,
                            site_properties=structure.site_properties)
-
+        
         self._spacegroup = spacegroup
-        site_map = zip(self._sites, equivalent_positions)
-        site_map = sorted(site_map, key=lambda x: x[1])
-        self._equivalent_sites = [
-            [x[0] for x in g] for k, g
-            in itertools.groupby(site_map, key=lambda x: x[1])]
+        u, inv = np.unique(equivalent_positions, return_inverse = True)
+        self.equivalent_indices = [[] for i in xrange(len(u))]
+        self._equivalent_sites = [[] for i in xrange(len(u))]
+        for i, inv in enumerate(inv):
+            self.equivalent_indices[inv].append(i)
+            self._equivalent_sites[inv].append(self.sites[i])
 
     @property
     def equivalent_sites(self):
