@@ -24,7 +24,6 @@ import vtk
 
 from pymatgen.util.coord_utils import in_coord_list
 from pymatgen.core.periodic_table import Specie
-from pymatgen.core.structure_modifier import SupercellMaker
 from pymatgen.core.structure import Structure
 
 
@@ -113,6 +112,7 @@ class StructureVis(object):
 
         style = StructureInteractorStyle(self)
         self.iren.SetInteractorStyle(style)
+        self.ren.parent = self
 
     def rotate_view(self, axis_ind=0, angle=0):
         """
@@ -221,10 +221,14 @@ class StructureVis(object):
                 on the structure.
         """
         self.ren.RemoveAllViewProps()
-        m = SupercellMaker(structure, self.supercell)
-        s = m.modified_structure
-        all_sites = [site.to_unit_cell for site in s]
-        s = Structure.from_sites(all_sites)
+
+        has_lattice = hasattr(structure, "lattice")
+
+        if has_lattice:
+            s = Structure.from_sites(structure, to_unit_cell=True)
+            s.make_supercell(self.supercell)
+        else:
+            s = structure
 
         inc_coords = []
         for site in s:
@@ -234,9 +238,9 @@ class StructureVis(object):
         count = 0
         labels = ["a", "b", "c"]
         colors = [(1, 0, 0), (0, 1, 0), (0, 0, 1)]
-        matrix = s.lattice.matrix
 
-        if self.show_unit_cell:
+        if self.show_unit_cell and has_lattice:
+            matrix = s.lattice.matrix
             self.add_text([0, 0, 0], "o")
             for vec in matrix:
                 self.add_line((0, 0, 0), vec, colors[count])
@@ -250,7 +254,6 @@ class StructureVis(object):
         if self.show_bonds or self.show_polyhedron:
             elements = sorted(s.composition.elements, key=lambda a: a.X)
             anion = elements[-1]
-
             def contains_anion(site):
                 for sp in site.species_and_occu.keys():
                     if sp.symbol == anion.symbol:
@@ -297,13 +300,19 @@ class StructureVis(object):
 
         camera = self.ren.GetActiveCamera()
         if reset_camera:
-            #Adjust the camera for best viewing
-            lengths = s.lattice.abc
-            pos = (matrix[1] + matrix[2]) * 0.5 + matrix[0] * max(lengths) / \
-                lengths[0] * 3.5
-            camera.SetPosition(pos)
-            camera.SetViewUp(matrix[2])
-        camera.SetFocalPoint((matrix[0] + matrix[1] + matrix[2]) * 0.5)
+            if has_lattice:
+                #Adjust the camera for best viewing
+                lengths = s.lattice.abc
+                pos = (matrix[1] + matrix[2]) * 0.5 + matrix[0] * max(lengths) / \
+                    lengths[0] * 3.5
+                camera.SetPosition(pos)
+                camera.SetViewUp(matrix[2])
+                camera.SetFocalPoint((matrix[0] + matrix[1] + matrix[2]) * 0.5)
+            else:
+                origin = s.center_of_mass
+                max_site = max(s, key=lambda site: site.distance_from_point(origin))
+                camera.SetPosition(origin + 5 * (max_site.coords - origin))
+                camera.SetFocalPoint(s.center_of_mass)
 
         self.structure = structure
         self.title = s.composition.formula
@@ -358,7 +367,7 @@ class StructureVis(object):
             sphere.SetEndTheta(end)
 
             mapper = vtk.vtkPolyDataMapper()
-            mapper.SetInput(sphere.GetOutput())
+            mapper.SetInputConnection(sphere.GetOutputPort())
             self.mapper_map[mapper] = [site]
             actor = vtk.vtkActor()
             actor.SetMapper(mapper)
@@ -429,14 +438,16 @@ class StructureVis(object):
         source.GetOutput().GetPointData().AddArray(vertexIDs)
 
         mapper = vtk.vtkPolyDataMapper()
-        mapper.SetInput(source.GetOutput())
+        mapper.SetInputConnection(source.GetOutputPort())
         actor = vtk.vtkActor()
         actor.SetMapper(mapper)
         actor.GetProperty().SetColor(color)
         actor.GetProperty().SetLineWidth(width)
         self.ren.AddActor(actor)
 
-    def add_polyhedron(self, neighbors, center, color):
+    def add_polyhedron(self, neighbors, center, color, opacity=0.4,
+                       draw_edges=False, edges_color=[0.0, 0.0, 0.0],
+                       edges_linewidth=2):
         """
         Adds a polyhedron.
 
@@ -447,6 +458,14 @@ class StructureVis(object):
                 The atom in the center of the polyhedron.
             color:
                 Color for text as RGB.
+            opacity:
+                Opacity of the polyhedron
+            draw_edges:
+                If set to True, the a line will be drawn at each edge
+            edges_color:
+                Color of the line for the edges
+            edges_linewidth:
+                Width of the line drawn for the edges
         """
         points = vtk.vtkPoints()
         conv = vtk.vtkConvexPointSet()
@@ -463,15 +482,99 @@ class StructureVis(object):
         polysites = [center]
         polysites.extend(neighbors)
         self.mapper_map[dsm] = polysites
-        dsm.SetInput(grid)
+        if vtk.VTK_MAJOR_VERSION <= 5:
+            dsm.SetInputConnection(grid.GetProducerPort())
+        else:
+            dsm.SetInputData(grid)
         ac = vtk.vtkActor()
         #ac.SetMapper(mapHull)
         ac.SetMapper(dsm)
-        ac.GetProperty().SetOpacity(0.4)
-        ac.GetProperty().SetColor(color)
+        ac.GetProperty().SetOpacity(opacity)
+        if color == 'element':
+            # If partial occupations are involved, the color of the specie with
+            # the highest occupation is used
+            myoccu = 0.0
+            for specie, occu in center.species_and_occu.items():
+                if occu > myoccu:
+                    myspecie = specie
+                    myoccu = occu
+            color = [i / 255 for i in self.el_color_mapping[myspecie.symbol]]
+            ac.GetProperty().SetColor(color)
+        else:
+            ac.GetProperty().SetColor(color)
+        if draw_edges:
+            ac.GetProperty().SetEdgeColor(edges_color)
+            ac.GetProperty().SetLineWidth(edges_linewidth)
+            ac.GetProperty().EdgeVisibilityOn()
         self.ren.AddActor(ac)
 
-    def add_bonds(self, neighbors, center):
+    def add_triangle(self, neighbors, color, center=None, opacity=0.4,
+                     draw_edges=False, edges_color=[0.0, 0.0, 0.0],
+                     edges_linewidth=2):
+        """
+        Adds a triangular surface between three atoms.
+
+        Args:
+            atoms:
+                Atoms between which a triangle will be drawn.
+            color:
+                Color for triangle as RGB.
+            center:
+                The "central atom" of the triangle
+            opacity:
+                opacity of the triangle
+            draw_edges:
+                If set to True, the a line will be drawn at each edge
+            edges_color:
+                Color of the line for the edges
+            edges_linewidth:
+                Width of the line drawn for the edges
+        """
+        points = vtk.vtkPoints()
+        triangle = vtk.vtkTriangle()
+        for ii in range(3):
+            points.InsertNextPoint(neighbors[ii].x, neighbors[ii].y,
+                                   neighbors[ii].z)
+            triangle.GetPointIds().SetId(ii,ii)
+        triangles = vtk.vtkCellArray()
+        triangles.InsertNextCell(triangle)
+
+        # polydata object
+        trianglePolyData = vtk.vtkPolyData()
+        trianglePolyData.SetPoints( points )
+        trianglePolyData.SetPolys( triangles )
+
+        # mapper
+        mapper = vtk.vtkPolyDataMapper()
+        mapper.SetInput(trianglePolyData)
+
+        ac = vtk.vtkActor()
+        ac.SetMapper(mapper)
+        ac.GetProperty().SetOpacity(opacity)
+        if color == 'element':
+            if center is None:
+                raise ValueError(
+                    'Color should be chosen according to the central atom, '
+                    'and central atom is not provided')
+            # If partial occupations are involved, the color of the specie with
+            # the highest occupation is used
+            myoccu = 0.0
+            for specie, occu in center.species_and_occu.items():
+                if occu > myoccu:
+                    myspecie = specie
+                    myoccu = occu
+            color = [i / 255 for i in self.el_color_mapping[myspecie.symbol]]
+            ac.GetProperty().SetColor(color)
+        else:
+            ac.GetProperty().SetColor(color)
+        if draw_edges:
+            ac.GetProperty().SetEdgeColor(edges_color)
+            ac.GetProperty().SetLineWidth(edges_linewidth)
+            ac.GetProperty().EdgeVisibilityOn()
+        self.ren.AddActor(ac)
+
+    def add_bonds(self, neighbors, center, color=None, opacity=None,
+                  radius=0.1):
         """
         Adds bonds for a site.
 
@@ -480,6 +583,12 @@ class StructureVis(object):
                 Neighbors of the site.
             center:
                 The site in the center for all bonds.
+            color:
+                Color of the tubes representing the bonds
+            opacity:
+                Opacity of the tubes representing the bonds
+            radius:
+                radius of tube s representing the bonds
         """
         points = vtk.vtkPoints()
         points.InsertPoint(0, center.x, center.y, center.z)
@@ -495,14 +604,21 @@ class StructureVis(object):
         pd.SetLines(lines)
 
         tube = vtk.vtkTubeFilter()
-        tube.SetInput(pd)
-        tube.SetRadius(0.1)
+        if vtk.VTK_MAJOR_VERSION <= 5:
+            tube.SetInputConnection(pd.GetProducerPort())
+        else:
+            tube.SetInputData(pd)
+        tube.SetRadius(radius)
 
         mapper = vtk.vtkPolyDataMapper()
         mapper.SetInputConnection(tube.GetOutputPort())
 
         actor = vtk.vtkActor()
         actor.SetMapper(mapper)
+        if opacity is not None:
+            actor.GetProperty().SetOpacity(opacity)
+        if color is not None:
+            actor.GetProperty().SetColor(color)
         self.ren.AddActor(actor)
 
     def add_picker_fixed(self):
@@ -593,16 +709,18 @@ class StructureInteractorStyle(vtk.vtkInteractorStyleTrackballCamera):
         return
 
     def leftButtonReleaseEvent(self, obj, event):
+        ren = obj.GetCurrentRenderer()
+        iren = ren.GetRenderWindow().GetInteractor()
         if self.mouse_motion == 0:
-            pos = self.parent.iren.GetEventPosition()
-            self.parent.picker.Pick(pos[0], pos[1], 0, self.parent.ren)
+            pos = iren.GetEventPosition()
+            iren.GetPicker().Pick(pos[0], pos[1], 0, ren)
         self.OnLeftButtonUp()
         return
 
     def keyPressEvent(self, obj, event):
-        parent = self.parent
+        parent = obj.GetCurrentRenderer().parent
         sym = parent.iren.GetKeySym()
-        #print sym
+
         if sym in "ABCabc":
             if sym == "A":
                 parent.supercell[0][0] += 1
